/*
 * Project name:
     Eeprom (Demonstration of using EEPROM Library)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Revision History:
     20110916:
       - initial release (FJ);
 * Description:
     This is a demonstration of using library functions for handling of the
     AVR's internal EEPROM module. First, some data is written to EEPROM
     then the data is read from the same locations and displayed on UARTC0
 * Test configuration:
     MCU:             ATxmega128A1
                      http://www.atmel.com/dyn/resources/prod_documents/doc8067.pdf
     Dev.Board:       Ready for XMEGA
                      http://www.mikroe.com/eng/products/view/755/ready-for-xmega-board/
     Oscillator:      Internal Clock 32.0000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - None.
 */

char ii;
char dta;

void main(){
  // Internal oscillator selection procedure
  OSC_CTRL = 0x02;  // 32MHz internal RC oscillator

  while(RC32MRDY_bit == 0)
   ;

  CPU_CCP = 0xD8;   // The CCP register must be written with the correct signature to enable change of the protected
                    // I/O register or execution of the protected instruction for a maximum of 4 CPU instruction cycles.
  CLK_CTRL = 1;     // Internal oscillator

  UARTC0_Init(19200);                  // Initialize UARTC0 at 19200 bps
  Delay_ms(100);
  
  for(ii = 0; ii < 0xFF; ii++)         // EEPROM write loop
    EEPROM_Write(0x100+ii, ii);        // Write data to address 0x100+ii

  for(ii = 0; ii < 0xFF; ii++) {       // EEPROM read loop
    dta = EEPROM_Read(0x100+ii);       // Read data from address 0x100+ii
    UARTC0_Write(dta);                 //   and display it on UARTC0
  }
}