/*
 * Project name:
     Piezo (Usage of Piezo speaker)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Revision History:
     20110916:
       - initial release (FJ);
 * Description:
     This project is a simple demonstration of how to
     use sound library for playing tones on a piezo speaker.
 * Test configuration:
     MCU:             ATxmega128A1
                      http://www.atmel.com/dyn/resources/prod_documents/doc8067.pdf
     Dev.Board:       Ready for XMEGA
                      http://www.mikroe.com/eng/products/view/755/ready-for-xmega-board/
     Oscillator:      Internal Clock 32.0000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - None.
 */

void Tone1() {
  Sound_Play(659, 250);   // Frequency = 659Hz, duration = 250ms
}

void Tone2() {
  Sound_Play(698, 250);   // Frequency = 698Hz, duration = 250ms
}

void Tone3() {
  Sound_Play(784, 250);   // Frequency = 784Hz, duration = 250ms
}

void Melody() {           // Plays the melody "Yellow house"
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone3(); Tone3(); Tone2(); Tone2(); Tone1();
}

void main() {

  // Internal oscillator selection procedure
  OSC_CTRL = 0x02;  // 32MHz internal RC oscillator

  while(RC32MRDY_bit == 0)
   ;

  CPU_CCP = 0xD8;   // The CCP register must be written with the correct signature to enable change of the protected
                    // I/O register or execution of the protected instruction for a maximum of 4 CPU instruction cycles.
  CLK_CTRL = 1;     // Internal oscillator

  PORTQ_DIRSET = 255;         // Set PORTQ as output
  Sound_Init(&PORTQ_OUT, 2);  // Initialize the pin PQ2 for playing sound

  Melody();         // Play Melody Yellow House
}